LiveTalkEndpoints class abstract final

Central registry for all LiveTalk API base URLs and endpoint paths. Update baseUrl or socketUrl here to switch environments.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

actionOnMessage → const String
baseUrl → const String
config → const String
GET config for a domain. Append /{domainPbx} when calling.
createRoom → const String
geo → const String
getCurrentRoom → const String
logout → const String
messageHistory → const String
removeMessage → const String
sendMedia → const String
sendMessage → const String
sendSticker → const String
socketUrl → const String