LiveTalkErrorCodes class abstract final

String constants for all LiveTalk SDK error keys. Consumers use these keys to look up localized messages in their i18n tables. Never display an errorKey directly to the end user.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited