LiveTalkSocketManager class

Properties

eventStream → Stream<LiveTalkEventEntity>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disconnect() → dynamic
liveTalkSocketConnected() → dynamic
liveTalkSocketConnectError() → dynamic
liveTalkSocketDisConnect() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startListenWebSocket(String token, String id, String tenantId) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

shareInstance → LiveTalkSocketManager
no setter