String constants for all LiveTalk SDK error keys. Consumers use these keys to look up localized messages in their i18n tables. Never display an errorKey directly to the end user.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- api → const String
- badGateway → const String
- conflict → const String
- emptyInfo → const String
- emptyPaths → const String
- emptyText → const String
- fileLimitExceeded → const String
- fileSizeExceeded → const String
- forbidden → const String
- gone → const String
- httpVersionNotSupp → const String
- insufficientStorage → const String
- invalidData → const String
- invalidPhone → const String
- lengthRequired → const String
- loginSessionExpired → const String
- methodNotAllowed → const String
- movedPermanently → const String
- noData → const String
- noInternet → const String
- notFound → const String
- notImplemented → const String
- notModified → const String
- outOfArea → const String
- payloadTooLarge → const String
- paymentRequired → const String
- preconditionFailed → const String
- proxyAuthRequired → const String
- rangeNotSatisfiable → const String
- requestTimeout → const String
- requestTimeoutHttp → const String
- sessionExpired → const String
- spamRequest → const String
- system → const String
- tooManyRequests → const String
- unknown → const String
- unprocessableEntity → const String
- unsupportedMediaType → const String
- uriTooLong → const String